Stan Math Library: stan/math/prim/scal/meta/contains_nonconstant_struct.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

contains_nonconstant_struct.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_CONTAINS_NONCONSTANT_STRUCT_HPP
2 #define STAN_MATH_PRIM_SCAL_META_CONTAINS_NONCONSTANT_STRUCT_HPP
3
4 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
5
6 namespace stan {
7
8 template <typename T1,
9 typename T2 = double,
10 typename T3 = double,
11 typename T4 = double,
12 typename T5 = double,
13 typename T6 = double>
14 struct contains_nonconstant_struct {
15 enum {
16 value = !is_constant_struct<T1>::value
17 || !is_constant_struct<T2>::value
18 || !is_constant_struct<T3>::value
19 || !is_constant_struct<T4>::value
20 || !is_constant_struct<T5>::value
21 || !is_constant_struct<T6>::value
22 };
23 };
24
25 }
26 #endif
27
stan
Definition: log_sum_exp.hpp:8
is_constant_struct.hpp
stan::is_constant_struct
Metaprogram to determine if a type has a base scalar type that can be assigned to type double...
Definition: is_constant_struct.hpp:13
stan::contains_nonconstant_struct
Definition: contains_nonconstant_struct.hpp:14
stan::contains_nonconstant_struct::value
Definition: contains_nonconstant_struct.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.